/* drag:toolbar scrollbar:overlay symbolic-icons:#dfdbd2 spinbox:touch modview:ts*/

QToolBar#MainToolBar { background-color: #3c3b37; border: 0px;} QToolBar#MainToolBar:active { background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #3c3b37, stop: 1 #575651); border: 0px;} QToolBar#MainToolBar QToolButton,QToolBar#MainToolBar QLabel { color: #bfbbb2;} QToolBar#MainToolBar QToolButton,QToolBar#MainToolBar QLabel:active { color: #dfdbd2;} QToolBar#MainToolBar QToolButton:disabled,QToolBar#MainToolBar QLabel:disabled { color: #9f9b92;} QToolBar#MainToolBar QToolButton { background: transparent; border: 1px outset transparent;} QToolBar#MainToolBar QToolButton:hover { background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #464640, stop: 1 #303025); border-radius: 5px; border: 1px outset #3c3b37;} QToolBar#MainToolBar QToolButton:pressed,QToolBar#MainToolBar QToolButton:checked { background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #383730, stop: 1 #2b2c27); border-radius: 5px; border: 1px inset #292825;} QToolBar#MainToolBar:separator { width: 1px; background: #3f3b32; margin-top: 4px; margin-bottom: 4px; margin-left: 7px; margin-right: 7px;} 

QMenu { background-color: #363531; color: #dfdbd2; padding: 1px;} QMenu QLabel { color: #dfdbd2;} QMenu:active { background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #e07746, stop: 1 #d05726); color: #dfdbd2;} QMenu:disabled { background-color: #363531; color: #8f8b82;} QMenu::separator { background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2b2a26, stop: 1 #4b4a46); height: 2;} /*QMenu::separator { background-color: #2b2a26; height: 1;} */

MirrorMenu { background-color: #363531; color: #dfdbd2; padding: 1px;} MirrorMenu QLabel { color: #dfdbd2;} MirrorMenu:active { background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #e07746, stop: 1 #d05726); color: #dfdbd2;} MirrorMenu:disabled { background-color: #363531; color: #8f8b82;} MirrorMenu::separator { background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2b2a26, stop: 1 #4b4a46); height: 2;} /*MirrorMenu::separator { background-color: #2b2a26; height: 1;} */
