/* drag:toolbar scrollbar:overlay symbolic-icons:#2d3335 spinbox:touch*/

QToolBar#MainToolBar { border: 0px;} QToolBar#MainToolBar QToolButton,QToolBar#MainToolBar QLabel { color: #a7aaa7;} QToolBar#MainToolBar QToolButton,QToolBar#MainToolBar QLabel:active { color: #2d3335;} QToolBar#MainToolBar QToolButton { background: transparent; border: 1px outset transparent;} QToolBar#MainToolBar QToolButton:hover { background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #f7f7f7, stop: 1 #dcdcdc); border-radius: 3px; border: 1px solid #b2b6b2;} QToolBar#MainToolBar QToolButton:pressed,QToolBar#MainToolBar QToolButton:checked { background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #a8aca8, stop: 1 #e0e0e0); border-radius: 3; border: 1px solid #bdbfbd;} 
