/* drag:toolbar scrollbar:overlay symbolic-icons:#404040 spinbox:touch*/

QToolBar#MainToolBar { background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #dedede, stop: 1 #bbbbbb); border: 0px;} QToolBar#MainToolBar QToolButton,QToolBar#MainToolBar QLabel { color: #3c3c3c;} QToolBar#MainToolBar QToolButton { background: transparent; border: 1px outset transparent;} QToolBar#MainToolBar QToolButton:hover { background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #eeeeee, stop: 1 #d8d8d8); border-radius: 4px; border: 1px outset #606060;} QToolBar#MainToolBar QToolButton:pressed,QToolBar#MainToolBar QToolButton:checked { background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #a0a0a0, stop: 1 #d8d8d8); border-radius: 4px; border: 1px inset #505050;} 

QMenu::separator { background-color: #ececec; height: 1;} 

MirrorMenu::separator { background-color: #ececec; height: 1;} 
